function plot_example_mode(mode1, PC, mn, V, aligned_mesh, temp_full_mesh)
%Principal components, mean, eigenvalues, airway mesh, logical plot choice

%temp_full_mesh - entire mesh of the case used as the template the template
%aligned_mesh - template section of the mesh that was aligned to all cases

%% CHECKS
%Checking if this is the matched template or a case that still needs to be
%matched

disp('reducing mesh for export')
temp_full_mesh=reducepatch(temp_full_mesh, 0.1);

if ~isfield(temp_full_mesh, 'matchred')
    disp('Not using original template for visaulisation')
    disp('Generating matching point set...')
    temp_full_mesh.matchred=find_matchred(temp_full_mesh, aligned_mesh);
end

%% Variables
fnum=mode1; %number of modes
plotspan=[min(mn) max(mn)];

%% Aligning template to the mean of the dataset 
% using generalised procrustes (with matchred as the landmark points)

%calculationg the rigid deformation of the branch of interest to the template
[~,~,zdef]=procrustes(threecol(mn), temp_full_mesh.vertices(temp_full_mesh.matchred,:)); tem_size=size(temp_full_mesh.vertices);
%warping the entire template using the deformation
tem_p.vertices=zdef.b*temp_full_mesh.vertices*zdef.T+repmat(zdef.c(1,:), tem_size(1), 1);

% test plot
% figure, plttr2(aligned_mesh.faces, threecol(mn), temp_full_mesh.faces, tem_p.vertices);


%% calculating modes of variation
ccg=0;
bm1{fnum, 1}=threecol(mn+PC(:,fnum)*(3*sqrt(V(fnum))));      %mean + first mode
bm1{fnum, 2}=threecol(mn); %mean 
bm1{fnum, 3}=threecol(mn+PC(:,fnum)*(-3*sqrt(V(fnum))));   %mean - first mode

% just the PCA mode
figure('Color', [1 1 1]),
pnpn={strcat('mean + mode', num2str(fnum)) 'mean' strcat('mean - mode', num2str(fnum))};
for jj=1:3
    ccg=ccg+1;
    %figure,
    subplot(1,3,jj),
    plttr(aligned_mesh.faces, bm1{fnum,jj}, plotspan)
    title(pnpn(jj))
    %saveas(gcf,strcat(num2str(ccg), '.fig'),'fig');
end
pos_fig=get(gcf, 'OuterPosition');
set(gcf, 'OuterPosition', [100 100 pos_fig(3)*2, pos_fig(4)*2]);

% warping template onto branch (using piecewise deformation)
figure('Color', [1 1 1])
for jj=1:3
    subplot(1,3,jj), % plotting all in same figure
    warpimg=s1Piecewisewarp_deformfield_distred(tem_p.vertices, tem_p.vertices(temp_full_mesh.matchred,:), bm1{fnum,jj});
    plttr2(aligned_mesh.faces, bm1{fnum,jj}, temp_full_mesh.faces, warpimg);
    title(pnpn(jj))
end
pos_fig=get(gcf, 'OuterPosition');
set(gcf, 'OuterPosition', [100 100 pos_fig(3)*2, pos_fig(4)*2]);

end

function [matchred]=find_matchred(vm, vam)
    matchred=zeros(size(vam.vertices, 1),1);
    for ii=1:size(vam.vertices, 1)
        z=edist_vec(vm.vertices, vam.vertices(ii, :));
        [~, matchred(ii)]=min(z);
    end
    
end

function [z]=edist_vec(x,y)

    % euclidean distance between two points
    if size(y, 1)==1
        y=repmat(y, size(x, 1), 1);
    end
    
    z=(sum(((x-y).^2), 2)).^0.5;
end

function [bm2]=threecol(bm1)
    np=length(bm1)/3;
    bm2=[bm1(1:np) bm1(np+1:2*np) bm1(2*np+1:3*np)];
end

function plttr(tface, tvert, plotspan)
%plots one mesh
p=patch('Faces',tface,'Vertices', g1flipper3(tvert));
set(p,'FaceColor','blue','EdgeColor','none');

axis equal
axis([plotspan(1) plotspan(2) plotspan(1) plotspan(2) plotspan(1) plotspan(2)])

alpha(p, 0.8);
xxx=[1 0 0];
rotate(p, xxx, 180)
view(-10,30);
lighting gouraud;
camlight;
end

function plttr2(tface1, tvert1, tface2, tvert2)
%plots two meshes
p=patch('Faces',tface1,'Vertices', g1flipper3(tvert1));
set(p,'FaceColor','blue','EdgeColor','none');
q=patch('Faces',tface2,'Vertices', g1flipper3(tvert2));
set(q,'FaceColor','blue','EdgeColor','none');

axis equal

axis([min(tvert2(:,2)) max(tvert2(:,2)) min(tvert2(:,1)) max(tvert2(:,1)) min(tvert2(:,3)) max(tvert2(:,3))])
axis off

alpha(p, 0.8);
alpha(q, 0.1)
xxx=[1 0 0];
rotate(p, xxx, 180)
rotate(q, xxx, 180)
view(-10,30);
lighting gouraud;
camlight;
end

function [casedat]=g1flipper3(casedat)
%flips the x and y coordinates (takes just casedat.vertices). more flexible.
    for jj=1:size(casedat, 1)
        casedat(jj,:)=casedat(jj,[2 1 3]);
    end
end